//$Id: label-canvas.h,v 1.3 2001/10/18 19:08:51 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_LABEL_CANVAS_H
#define GUIKACHU_FORM_EDITOR_LABEL_CANVAS_H

#include "label.h"

#include <gnome--/canvas-group.h>

using Guikachu::Widgets::Label;
using namespace Guikachu::GUI::FormEditor;

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class LabelCanvasItem: public CanvasItem
	    {
		Widgets::Label     *widget;
		Gnome::CanvasGroup *group;
	    public:
		LabelCanvasItem (Widgets::Label   *widget,
				 FormEditor::Form *form);
	    protected:
		virtual void update ();
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_LABEL_CANVAS_H */
